@@ -27,7 +27,7 @@ import (
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	apiruntime "k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/util/sets"
-	"k8s.io/klog"
+	"k8s.io/klog/v2"
 )
 
 // renderOpts holds values to drive the render command.
@@ -38,7 +38,6 @@ type renderOpts struct {
 	errOut                   io.Writer
 	etcdCAFile               string
 	etcdCAKeyFile            string
-	unusedEtcdMetricCAFile   string
 	etcdDiscoveryDomain      string
 	etcdImage                string
 	clusterEtcdOperatorImage string
@@ -125,10 +124,8 @@ func (r *renderOpts) AddFlags(fs *pflag.FlagSet) {
 	r.manifest.AddFlags(fs, "etcd")
 	r.generic.AddFlags(fs)
 
-	fs.StringVar(&r.etcdCAFile, "etcd-ca", r.etcdCAFile, "path to etcd CA certificate")
+	fs.StringVar(&r.etcdCAFile, "etcd-ca", "/assets/tls/etcd-ca-bundle.crt", "path to etcd CA certificate")
 	fs.StringVar(&r.etcdCAKeyFile, "etcd-ca-key", "/assets/tls/etcd-signer.key", "path to etcd CA certificate key")
-	// deprecated
-	fs.StringVar(&r.unusedEtcdMetricCAFile, "etcd-metric-ca", r.unusedEtcdMetricCAFile, "path to etcd metric CA certificate")
 	fs.StringVar(&r.etcdImage, "manifest-etcd-image", r.etcdImage, "etcd manifest image")
 	fs.StringVar(&r.clusterEtcdOperatorImage, "manifest-cluster-etcd-operator-image", r.clusterEtcdOperatorImage, "cluster-etcd-operator manifest image")
 	fs.StringVar(&r.kubeClientAgentImage, "manifest-kube-client-agent-image", r.kubeClientAgentImage, "kube-client-agent manifest image")
@@ -155,18 +152,9 @@ func (r *renderOpts) Validate() error {
 	if len(r.etcdImage) == 0 {
 		return errors.New("missing required flag: --manifest-etcd-image")
 	}
-	if len(r.kubeClientAgentImage) == 0 {
-		return errors.New("missing required flag: --manifest-kube-client-agent-image")
-	}
-	if len(r.setupEtcdEnvImage) == 0 {
-		return errors.New("missing required flag: --manifest-setup-etcd-env-image")
-	}
 	if len(r.clusterEtcdOperatorImage) == 0 {
 		return errors.New("missing required flag: --manifest-cluster-etcd-operator-image")
 	}
-	if len(r.etcdDiscoveryDomain) == 0 {
-		return errors.New("missing required flag: --etcd-discovery-domain")
-	}
 	if len(r.networkConfigFile) == 0 {
 		return errors.New("missing required flag: --cluster-config-file")
 	}
@@ -231,8 +219,7 @@ func newTemplateData(opts *renderOpts) (*TemplateData, error) {
 	templateData := TemplateData{
 		ManifestConfig: options.ManifestConfig{
 			Images: options.Images{
-				Etcd:            opts.etcdImage,
-				KubeClientAgent: opts.kubeClientAgentImage,
+				Etcd: opts.etcdImage,
 			},
 		},
 		EtcdServerCertDNSNames: strings.Join([]string{
